@@ -1,7 +1,7 @@
 from configobj import ConfigObj
 
 
-def parse_ini_file(path_to_ini_file):
+def parse_ini_file(path_to_ini_file: str) -> dict:
     """take a path to a INI file & returns it as a valid python dict.
 
             Arguments:
